'use strict';

exports.__esModule = true;
exports.ProxyProvider = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactApollo = require('react-apollo');

var _apolloClient = require('apollo-client');

var _apolloClient2 = _interopRequireDefault(_apolloClient);

var _unfetch = require('unfetch');

var _unfetch2 = _interopRequireDefault(_unfetch);

var _apolloLinkHttp = require('apollo-link-http');

var _apolloCacheInmemory = require('apollo-cache-inmemory');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Return the children with an ApolloClient which defaults to point at
 *   http://proxy-graphql.herokuapp.com.
 *
 * @param {Object} props - The component props.
 * @param {ApolloClient} [props.uri] - The GraphQL endpoint.
 * @param {ApolloClient} [props.client] - The Apollo client.
 * @returns {Component} An ApolloProvider with a custom client.
 *
 * @example <caption>Display users' names from GraphQL API</caption>
 * <ProxyProvider>
 *   <Action
 *     url="https://proxy-graphql.herokuapp.com"
 *     action="query Q { test }"
 *   >
 *     <Put />
 *   </Action>
 * </ProxyProvider>
 */
var ProxyProvider = exports.ProxyProvider = function ProxyProvider(_ref) {
  var _ref$uri = _ref.uri,
      uri = _ref$uri === undefined ? 'https://proxy-graphql.herokuapp.com' : _ref$uri,
      client = _ref.client,
      children = _ref.children;
  return _react2.default.createElement(
    _reactApollo.ApolloProvider,
    {
      client: client || new _apolloClient2.default({
        link: (0, _apolloLinkHttp.createHttpLink)({ uri: uri, fetch: _unfetch2.default }),
        cache: new _apolloCacheInmemory.InMemoryCache()
      })
    },
    children
  );
};